@@ -6,7 +6,7 @@ import functools
 # noinspection SpellCheckingInspection
 class Catalog(object):
     """Container interface to the SXS catalog"""
-    url = "https://data.black-holes.org/catalog.json"
+    url = "https://data.black-holes.org/catalog.zip"
 
     def __init__(self, catalog=None, **kwargs):
         from .. import Metadata
@@ -54,6 +54,19 @@ class Catalog(object):
         from .. import sxs_directory, read_config
         from ..utilities import download_file
 
+        from warnings import warn
+        deprecation_notice = """
+
+        You have called a function that uses the `Catalog` class,
+        which, as of `sxs` version 2024.0.0, has been deprecated in
+        favor of the `Simulations` interface.  See the documentation
+        for more information.
+
+        THIS CAN ONLY PROVIDE OLD DATA!
+
+        """
+        warn(deprecation_notice)
+
         progress = read_config("download_progress", True)
 
         cache_path = sxs_directory("cache") / "catalog.zip"
@@ -64,36 +77,12 @@ class Catalog(object):
             if_newer = False
 
         if download or download is None:
-            # 1. Download the full json file (zipped in flight, but auto-decompressed on arrival)
-            # 2. Zip to a temporary file (using bzip2, which is better than the in-flight compression)
-            # 3. Replace the original catalog.zip with the temporary zip file
-            # 4. Remove the full json file
-            # 5. Make sure the temporary zip file is gone too
-            temp_json = cache_path.with_suffix(".temp.json")
-            temp_zip = cache_path.with_suffix(".temp.zip")
             try:
-                try:
-                    download_file(cls.url, temp_json, progress=progress, if_newer=if_newer)
-                except Exception as e:
-                    if download:
-                        raise RuntimeError(f"Failed to download '{cls.url}'; try setting `download=False`") from e
-                    download_failed = e  # We'll try the cache
-                else:
-                    download_failed = False
-                    if temp_json.exists():
-                        with zipfile.ZipFile(temp_zip, "w", compression=zipfile.ZIP_BZIP2) as catalog_zip:
-                            catalog_zip.write(temp_json, arcname="catalog.json")
-                        temp_zip.replace(cache_path)
-            finally:
-                # The `missing_ok` argument to `unlink` would be much nicer, but was added in python 3.8
-                try:
-                    temp_json.unlink()
-                except FileNotFoundError as e:
-                    pass
-                try:
-                    temp_zip.unlink()
-                except FileNotFoundError as e:
-                    pass
+                download_file(cls.url, cache_path, progress=progress, if_newer=if_newer)
+            except Exception as e:
+                if download:
+                    raise RuntimeError(f"Failed to download '{cls.url}'; try setting `download=False`") from e
+                download_failed = e  # We'll try the cache
 
         if not cache_path.exists():
             if download_failed:
